#!/usr/bin/perl

# Fix Delivery Address
#
# usage: deliveryfix.pl [-r] oldnetid@email.address newnetid@email.address
# -r option performs a case-insensitive search of oldnetid@email.address
#

package RatsServerLib;
require 5.001;
require "/usr/local/accounts/lib/RatsClientLib.pm";
require "/usr/local/accounts/etc/rats_internal.conf";

use DBI;
#DBI->trace( 16, '/tmp/dbitrace.log' ) ;
use Sys::Hostname;
use File::Basename;
$do = \&RatsClientLib::send_remote_command;
$c_port=$CONFIG::CLIENT_PORT;
$s_port=$CONFIG::SERVER_PORT;
$master = $CONFIG::RATS_MASTER;

my $debug = $CONFIG::COMMAND_HOOKS{'DEBUG'};
my $log = $CONFIG::COMMAND_HOOKS{'LOG'};
my $old_address, $new_address;
my $case_insensitive = 0;

my $num_args = $#ARGV + 1;
if ($num_args < 2) {
    print "Not enough arguments\n";
    exit;
}
if ($num_args == 3) {
    if ($ARGV[0] ne "-r") {   # case insensitive search
        print "Unknown argument: $ARGV[0]\n";
        exit;
    }
    $case_insensitive = 1;
    $old_address = $ARGV[1];
    $new_address = $ARGV[2];
}
else {
    ($old_address, $new_address) = @ARGV;
} 

my ($netid, $stuff) = split("@", $new_address);

my $response = &$do('GETIRFL_U', $netid, $master, $s_port);
my ($code, @data) = split(":", $response);
unless ($code eq $CONFIG::API{'RETIRFL_U'}) {
    print "Couldn't find an RCPID for $netid\n";
    exit;
}

$rcpid = $data[1];

$response = &$do('GETDELIVERY', $rcpid, $master, $s_port);
my ($code, @data) = split(":", $response);
unless ($code eq $CONFIG::API{'RETGETDELIV'}) {
    print "Couldn't find delivery addresses for $netid/$rcpid. This might be ok\n";
    exit;
}

my $search_old_address = $old_address;
if ($case_insensitive == 1) {
    $search_old_address = lc($search_old_address);
}

foreach my $delivery (@data) {
    if ($delivery eq $search_old_address) {
        $response = &$do('REMDELIVERY', $rcpid, $delivery, $master, $s_port);
        my ($code1, @data1) = split(":", $response);
        unless ($code1 eq $CONFIG::API{'RETDELDELIV'}) {
            print "failed to delete delivery $delivery: $response\n";
            exit;
        }
        $response = &$do('SETDELIVERY', $rcpid, $rcpid, $new_address,"C", $master, $s_port);
        my ($code1, @data1) = split(":", $response);
        if ($code1 eq $CONFIG::API{'RETSSDELIV'}) {
            print "failed to set delivery $new_address: $response\n";
            exit;
        }
        print "$delivery replaced with $new_address\n";
    }
}
